Module: BigBench::Tracker

Defined in:
lib/bigbench/tracker.rb

Overview

The tracker records all request results a benchmark makes. When the benchmark is finished, the trackings are written depending on the mode of BigBench:

[config.mode == :bot] All trackings are appended to the redis store's tracking key [config.mode == :local] All trackings are written straight to the file defined by config.output [config.mode == :bots] All trackings are imported from the redis store's tracking key and written to the file defined by config.output

Defined Under Namespace

Classes: Tracker